@@ -132,7 +132,7 @@ class ScanCommand:
                         currentY = self._controller.extVcm.get_angle_y()
                         activeCavity = self._controller.get_active_cavity_index()
 
-                        detectorVoltage = self._controller.adc.read()
+                        detectorVoltage = self._controller.adc.read_fast()
                         self.results['active_cavity'].append(activeCavity)
                         self.results['x_set_point'].append(posX)
                         self.results['x'].append(currentX)
@@ -275,12 +275,13 @@ class FastScanCommand:
                     interpY = numpy.interp(detectorTimes, vcmTimes, vcmY)
 
                     activeCavity = self._controller.get_active_cavity_index()
-                    self.results['active_cavity'].append(activeCavity)
+
 
                     measured_wl = cavity.get_wavelength()
 
                     self.results['x'].extend(interpX.tolist())
                     self.results['y'].extend(interpY.tolist())
+                    self.results['active_cavity'].extend(len(interpX.tolist())*[activeCavity])
                     self.results['wavelength_set_point'].extend(len(interpX.tolist())*[wavelength])
                     self.results['wavelength'].extend(len(interpX.tolist())*[measured_wl])
                     self.results['detector_voltage'].extend(detectorValues.tolist())
